# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.urls import path, re_path

from . import api_views

urlpatterns = [
    path('register/', api_views.register, name='a2-api-register'),
    path('password-change/', api_views.password_change, name='a2-api-password-change'),
    path('user/', api_views.user, name='a2-api-user'),
    re_path(
        r'^users/(?P<user_uuid>[\w+]*)/profiles/(?P<profile_type_slug>[^/]+)/$',
        api_views.user_profiles,
        name='a2-api-user-profiles',
    ),
    re_path(
        r'^roles/(?P<role_uuid>[\w+]*)/members/$',
        api_views.roles_members,
        name='a2-api-role-members-list',
    ),
    re_path(
        r'^roles/(?P<role_uuid>[\w+]*)/members/(?P<member_uuid>[^/]+)/$',
        api_views.role_membership,
        name='a2-api-role-member',
    ),
    re_path(
        r'^roles/(?P<role_uuid>[\w+]*)/relationships/members/$',
        api_views.role_memberships,
        name='a2-api-role-members',
    ),
    re_path(
        r'^roles/(?P<role_uuid>[0-9a-z]{32})/parents/$',
        api_views.roles_parents,
        name='a2-api-role-parents',
    ),
    re_path(
        r'^roles/(?P<role_uuid>[0-9a-z]{32})/relationships/parents/$',
        api_views.roles_parents_relationships,
        name='a2-api-role-parents-relationships',
    ),
    path('check-password/', api_views.check_password, name='a2-api-check-password'),
    path('check-api-client/', api_views.check_api_client, name='a2-api-check-api-client'),
    path('validate-password/', api_views.validate_password, name='a2-api-validate-password'),
    path('password-strength/', api_views.password_strength, name='a2-api-password-strength'),
    path('address-autocomplete/', api_views.address_autocomplete, name='a2-api-address-autocomplete'),
]

urlpatterns += api_views.router.urls
